Component({
    /**
     * 组件的属性列表
     */
    properties: {
        brands: Object,
        roomtype: Object,
        roomlistings: Object,
        screen_data: Object,
        money: Object,

        operationstype: {
            type: String,
            observer(res) {
                let conditionAllConfig = this.data.conditionAllConfig
                this.setData({
                    conditionObj: conditionAllConfig[res]
                })
            }
        },
        location: {
            type: Object,
            observer(res) {
                let data = res.data
                if (!data) return
                let targetData = {}
                for (let key in data) {
                    key = Number(key)
                    if (key % 1 === 0) {
                        targetData[key] = {}
                        targetData[key]['title'] = data[key]
                    } else {
                        if (!targetData[Math.trunc(key)]['data']) targetData[Math.trunc(key)]['data'] = {
                            0: "不限"
                        }
                        targetData[Math.trunc(key)]['data'][key] = data[key]
                    }
                }
                this.setData({
                    areaData: targetData
                })
            }
        },

        school: {
            type: Object,
            observer(res) {
                let list = res.list
                list[0] = "不限"
                this.setData({
                    schoolData: res.list,
                    schoolValue: res.value || 0
                })
            }
        },
        types: {
            type: Object,
            observer(res) {
                let data = res.data
                let targetData = {}
                for (let key in data) {
                    key = Number(key)
                    if (key % 1 === 0) {
                        targetData[key] = {}
                        targetData[key]['title'] = data[key]
                    } else {
                        if (!targetData[Math.trunc(key)]['data']) targetData[Math.trunc(key)]['data'] = {
                            0: "不限"
                        }
                        targetData[Math.trunc(key)]['data'][key] = data[key]
                    }
                }
                console.log(res, 0);
            }
        }

    },

    /**
     * 组件的初始数据
     */
    data: {
        conditionState: "types", // brand  rent house  floor  school
        conditionAllConfig: {
            student: {
                brand: {
                    name: "品牌",
                    valueKey: "brands"
                },
                rent: {
                    name: "租金",
                },
                house: {
                    name: "房型",
                    valueKey: "roomtype"
                },
                floor: {
                    name: "楼型",
                    valueKey: "roomlistings"
                },
            },
            housing: {
                school: {
                    name: "区域",
                    valueKey: "brands"
                },
                types: {
                    name: "出租方式",
                    valueKey: "types"
                },
                rent: {
                    name: "租金",
                },
                moreCondition: {
                    name: "更多",
                    valueKey: "brands"
                },
                orderby: {
                    name: "最新",
                    valueKey: "orderby",
                    valueText: "最新",
                },
            }
        },
        conditionObj: {},
        rent: {
            min: 1000,
            max: 50000,
            rate: 490,
            defaultMin: 50, // 
            defaultMax: 80,
            step: 100,
            for: 491
        },

        rentValue: [40, 80],

        areaState: "area", // area school  区域 弹窗的状态 
        areaData: {}, // 区域弹窗的数据
        areaPitchValueOne: 0, //  区域选中 的 一级
        areaPitchValueTwo: { //  区域选中 的 二级
            0: true
        },

        schoolData: {}, // 学校弹窗 数据
        schoolValue: "", // 学校弹窗 选中数据
        orderby: {
            value: 'timestamp',
            list: {
                "timestamp": "最新发布",
                "hotnum": "热门",
                "rentasc": "价格从低到高",
                "rentdesc": "价格从高到低",
            },
            obj: {
                "timestamp": "最新发布",
                "hotnum": "热门",
                "rentasc": "价格从低到高",
                "rentdesc": "价格从高到低",
            },
        },
    },

    /**
     * 组件的方法列表
     */
    methods: {
        setValue(e) {
            let {
                key,
                value
            } = e.currentTarget.dataset

            this.setData({
                [key]: value
            })
            console.log(this.data.conditionState);

        },

        changeItem(e) {
            let conditionState = this.data.conditionState
            let {
                value,
            } = e.currentTarget.dataset

            let conditionObj = this.data.conditionObj
            let valueKey = conditionObj[conditionState].valueKey
            let obj = this.data[valueKey].obj
            conditionObj[conditionState]['valueText'] = obj[value]

            this.triggerEvent('submitarea', {
                type: conditionState,
                value
            })

            this.setData({
                conditionState: "",
                conditionObj
            })
        },

        // 滑动租金数据 事件
        bindChangeRent(e) {
            let value = e.detail.value
            this.setData({
                rentValue: value
            })
        },

        // 处理 租金的 事件
        handleRant(e) {
            let type = e.currentTarget.dataset.type
            let conditionState = this.data.conditionState
            let rentValue = this.data.rentValue
            let rent = this.data.rent
            rentValue.sort()
            let rent_min = 0
            let rent_max = 0
            let conditionObj = this.data.conditionObj
            if (type != 'unlimited') {
                rent_min = (rentValue[0] * rent['step']) + rent['min']
                rent_max = (rentValue[1] * rent['step']) + rent['min']
                conditionObj[conditionState]['valueText'] = `${rent_min} ~ ${rent_max}`
            } else conditionObj[conditionState]['valueText'] = ""

            this.triggerEvent('submit', {
                type: conditionState,
                rent_min,
                rent_max,
            })

            this.setData({
                conditionState: "",
                conditionObj
            })
        },

        // 处理区域选择 的 二级 
        handleAreaPitchValueTwo(e) {
            let {
                value
            } = e.currentTarget.dataset
            let areaPitchValueTwo = this.data.areaPitchValueTwo
            if (value == 0) {
                areaPitchValueTwo = {
                    0: true
                }
            } else {
                delete areaPitchValueTwo[0]
                if (areaPitchValueTwo[value]) areaPitchValueTwo[value] = false
                else areaPitchValueTwo[value] = true
            }
            this.setData({
                areaPitchValueTwo,
            })
        },

        // 点击区域弹窗 的确定
        clickAreaPitch(e) {
            let {
                type
            } = e.currentTarget.dataset

            let conditionObj = this.data.conditionObj
            let conditionState = this.data.conditionState

            let areaPitchValueOne = this.data.areaPitchValueOne
            let areaPitchValueTwo = this.data.areaPitchValueTwo
            let areaData = this.data.areaData

            if (type == "reset") {
                this.setData({
                    areaPitchValueOne: 0,
                    areaPitchValueTwo: {
                        0: true
                    },
                })
            } else {
                let location = []

                if (!areaPitchValueTwo[0]) { // 选择二级的
                    for (const key in areaPitchValueTwo) {
                        if (areaPitchValueTwo[key]) location.push(key)
                    }
                } else location.push(areaPitchValueOne) // 选择一级的
                conditionObj[conditionState]['valueText'] = `${ (areaData[areaPitchValueOne] && areaData[areaPitchValueOne].title) || '港岛' }/...`
                this.setData({
                    conditionState: "",
                    conditionObj,
                })
                this.triggerEvent("submitarea", {
                    school: "",
                    location
                })
            }

        },


        // 处理学校 选中
        handleSchoolPitchValue(e) {
            let value = e.currentTarget.dataset.value
            let conditionObj = this.data.conditionObj
            let conditionState = this.data.conditionState

            conditionObj[conditionState]['valueText'] = "学校"
            this.setData({
                schoolValue: value,
                areaPitchValueOne: 0,
                areaPitchValueTwo: {
                    0: true
                },
                conditionObj,
                conditionState: "",
            })

            this.triggerEvent("submitarea", {
                school: value,
                location: []
            })

        },

        // 处理点击 排序
        submitOrderby(e) {
            let value = e.currentTarget.dataset.value

            let conditionObj = this.data.conditionObj
            let orderby = this.data.orderby
            let conditionState = this.data.conditionState
            orderby["value"] = value
            conditionObj[conditionState]['valueText'] = orderby['list'][value]
            this.setData({
                orderby,
                conditionObj,
                conditionState: "",
            })
            console.log(conditionState);

            this.triggerEvent("submit", {
                value,
                type: conditionState
            })
        },
    }
})